@@ -1,7 +1,7 @@
 import os
 import asyncio
 import click
-from appended import appended
+from .append_path import appended
 from file_tools import BMWFileFactory
 """
 Take a folder containing a BMW backup and unpack it into a regular music folder
